@@ -1,6 +1,6 @@
 package Memcached::Client::Log;
 BEGIN {
-  $Memcached::Client::Log::VERSION = '1.99_03';
+  $Memcached::Client::Log::VERSION = '1.01';
 }
 # ABSTRACT: Logging support for Memcached::Client
 
@@ -8,10 +8,9 @@ use strict;
 use warnings;
 use Data::Dumper qw{Dumper};
 use IO::File qw{};
-use Scalar::Util qw{blessed};
 use base qw{Exporter};
 
-our @EXPORT = qw{DEBUG LOG};
+our @EXPORT = qw{DEBUG INFO};
 
 
 # Hook into $SIG{__WARN__} if you want to route these debug messages
@@ -21,45 +20,29 @@ BEGIN {
 
     if (exists $ENV{MCTEST} and $ENV{MCTEST}) {
         $ENV{MCDEBUG} = 1;
-        open $log, ">>", ",,debug.log" or die "Couldn't open ,,debug.log";
+        open $log, "+>>,,debug.log" or die "Couldn't open ,,debug.log";
         $log->autoflush (1);
     }
 
-    if ($ENV{MCDEBUG}) {
-        *DEBUG = sub () {1};
-    } else {
-        *DEBUG = sub () {0};
-    }
-
-    *LOG = sub (@) {
+    *INFO = sub (@) {
         local $Data::Dumper::Indent = 1;
         local $Data::Dumper::Quotekeys = 0;
         local $Data::Dumper::Sortkeys = 1;
         local $Data::Dumper::Terse = 1;
         my $format = shift or return;
-        chomp (my $entry = @_ ? sprintf $format, map {
-            if (defined $_) {
-                if (ref $_) {
-                    if (blessed $_ and $_->can ('as_string')) {
-                        $_->as_string;
-                    } else {
-                        Dumper $_;
-                    }
-                } else {
-                    $_
-                }
-            } else {
-                '[undef]'
-            }
-        } @_ : $format);
-        # my $output = "$callerinfo[3] $entry\n";
-        my $output = "$entry\n";
+        chomp (my $entry = @_ ? sprintf $format, map { defined $_ ? ref $_ ? Dumper $_ : $_ : '[undef]' } @_ : $format);
         if ($ENV{MCTEST}) {
-            $log->print ($output);
+            $log->print ("$entry\n");
         } else {
-            warn $output;
+            warn "$entry\n";
         }
     };
+
+    if ($ENV{MCDEBUG}) {
+        *DEBUG = *INFO;
+    } else {
+        *DEBUG = sub (@) {};
+    }
 }
 
 1;
@@ -73,7 +56,7 @@ Memcached::Client::Log - Logging support for Memcached::Client
 
 =head1 VERSION
 
-version 1.99_03
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -91,9 +74,9 @@ the structure of any references that are made.
 If the variable MCDEBUG is false, the debugging code should be
 compiled out entirely.
 
-=head2 LOG
+=head2 INFO
 
-LOG() will inform the user with the specified message, formatted with
+INFO() will warn the user with the specified message, formatted with
 sprintf and dumping the structure of any references that are made.
 
 =head1 AUTHOR
