@@ -1,12 +1,11 @@
 package Memcached::Client::Selector;
 BEGIN {
-  $Memcached::Client::Selector::VERSION = '1.99_03';
+  $Memcached::Client::Selector::VERSION = '1.01';
 }
 # ABSTRACT: Abstract Base Class For Memcached::Client Selector
 
 use strict;
 use warnings;
-use Memcached::Client::Log qw{LOG};
 
 
 sub new {
@@ -16,14 +15,6 @@ sub new {
 }
 
 
-sub log {
-    my ($self, $format, @args) = @_;
-    my $prefix = ref $self || $self;
-    $prefix =~ s,Memcached::Client::Selector::,Selector/,;
-    LOG ("$prefix> " . $format, @args);
-}
-
-
 sub set_servers {
     die "You must implement set_servers";
 }
@@ -44,7 +35,7 @@ Memcached::Client::Selector - Abstract Base Class For Memcached::Client Selector
 
 =head1 VERSION
 
-version 1.99_03
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -58,11 +49,6 @@ version 1.99_03
 
 C<new()> builds a new object.  It takes no parameters.
 
-=head2 C<log>
-
-Log the specified message with an appropriate prefix derived from the
-class name.
-
 =head2 set_servers
 
 C<set_servers()> will initialize the selector from the arrayref of
