@@ -1,20 +1,20 @@
 package Memcached::Client::Selector::Traditional;
 BEGIN {
-  $Memcached::Client::Selector::Traditional::VERSION = '1.99_03';
+  $Memcached::Client::Selector::Traditional::VERSION = '1.01';
 }
 #ABSTRACT: Implements Traditional Memcached Hashing
 
 use strict;
 use warnings;
-use Memcached::Client::Log qw{DEBUG};
+use Memcached::Client::Log;
 use String::CRC32 qw{crc32};
 use base qw{Memcached::Client::Selector};
 
 
 sub set_servers {
     my ($self, $list) = @_;
-    $self->log ("list: %s", $list) if DEBUG;
     if ($list) {
+        # DEBUG "S: Setting server list to %s", $list;
         my $count = scalar @{$list};
         if (1 < $count) {
             $self->{buckets} = [];
@@ -28,8 +28,9 @@ sub set_servers {
                 }
             }
             $self->{bucketcount} = scalar @{$self->{buckets}};
-            $self->log ("bucket count: %d\nbucket list: %s", $self->{bucketcount}, $self->{buckets}) if DEBUG;
+            # DEBUG "S: Bucket list is %s, bucket count is %d", $self->{buckets}, $self->{bucketcount};
         } elsif (1 == $count) {
+            # Handle ->set_servers ([['localhost:11211' => 5]])
             $self->{_single_sock} = ref $list->[0] ? $list->[0]->[0] : $list->[0];
         }
     } else {
@@ -48,7 +49,7 @@ sub get_server {
     return unless $self->{buckets};
     $namespace ||= "";
     my $hash = ref $key ? int ($key->[0]) : crc32 ($namespace . $key) >> 16 & 0x7fff;
-    $self->log ("Hash is %d, bucket # %d, bucket %s", $hash, $hash % $self->{bucketcount}, $self->{buckets}->[$hash % $self->{bucketcount}]) if DEBUG;
+    # DEBUG "S: Hash value is %s, bucket # is %s, bucket value is %s", $hash, $hash % $self->{bucketcount}, $self->{buckets}->[$hash % $self->{bucketcount}];
     return $self->{buckets}->[$hash % $self->{bucketcount}];
 }
 
@@ -63,7 +64,7 @@ Memcached::Client::Selector::Traditional - Implements Traditional Memcached Hash
 
 =head1 VERSION
 
-version 1.99_03
+version 1.01
 
 =head1 SYNOPSIS
 
